@@ -1,12 +1,16 @@
 # Inclui os membros
 
 from .cmarg00 import Cmarg00  # noqa
+from .cmarg00med import Cmarg00med  # noqa
+from .coper import Coper  # noqa
 from .eafbm00 import Eafbm00  # noqa
 from .earmfp00 import Earmfp00  # noqa
 from .earmfpm00 import Earmfpm00  # noqa
+from .earmfpsin import EarmfpSIN  # noqa
 from .ghtot00 import Ghtot00  # noqa
 from .ghtotm00 import Ghtotm00  # noqa
-from .gttotsin import GttotSIN  # noqa
+from .ghtotsin import GhtotSIN  # noqa
 from .mediasmerc import MediasMerc  # noqa
 from .mediassin import MediasSIN  # noqa
 from .vagua00 import Vagua00  # noqa
+from .varmuh import VarmUH  # noqa
